@@ -1,7 +1,7 @@
 /*
  *  Copyright © 2004 Adam Hooper
  *  Copyright © 2004, 2005 Jean-François Rameau
- *  Copyright © 2004, 2005 Christian Persch
+ *  Copyright © 2004, 2005, 2008 Christian Persch
  *
  *  Ripped from GaleonWrapper.cpp, which has no copyright info besides Marco...
  *
@@ -19,7 +19,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: mozilla-helpers.cpp 1632 2007-11-04 00:51:35Z cyrilbois $
+ *  $Id: mozilla-helpers.cpp 1728 2008-05-18 21:51:17Z chpe $
  */
 
 #include "mozilla-config.h"
@@ -27,6 +27,11 @@
 
 #include <string.h>
 
+#ifdef XPCOM_GLUE
+#include <nsXPCOMGlue.h>
+#include <gtkmozembed_glue.cpp>
+#endif
+
 #include <nsStringAPI.h>
 
 #include <gtkmozembed.h>
@@ -169,7 +174,7 @@ PageInfoHelper::Init (EphyEmbed *aEmbed)
   NS_ENSURE_ARG (aEmbed);
 
   nsCOMPtr<nsIWebBrowser> browser;
-  gtk_moz_embed_get_nsIWebBrowser (GTK_MOZ_EMBED (aEmbed),
+  gtk_moz_embed_get_nsIWebBrowser (GTK_MOZ_EMBED (gtk_bin_get_child (GTK_BIN (aEmbed))),
                                    getter_AddRefs (browser));
   NS_ENSURE_TRUE (browser, NS_ERROR_FAILURE);
 
@@ -1201,3 +1206,25 @@ mozilla_get_page_info (EphyEmbed *embed)
 
   return info;
 }
+
+gboolean
+mozilla_glue_startup (void)
+{
+#ifdef XPCOM_GLUE
+	static const GREVersionRange greVersion = {
+	  "1.9a", PR_TRUE,
+	  "2", PR_TRUE
+	};
+	char xpcomLocation[4096];
+
+	if (NS_FAILED (GRE_GetGREPathWithProperties(&greVersion, 1, nsnull, 0, xpcomLocation, sizeof (xpcomLocation))) ||
+	    NS_FAILED (XPCOMGlueStartup (xpcomLocation)) ||
+	    NS_FAILED (GTKEmbedGlueStartup ()) ||
+	    NS_FAILED (GTKEmbedGlueStartupInternal()))
+                return FALSE;
+
+        return TRUE;
+#else
+        return TRUE;
+#endif /* XPCOM_GLUE */
+}
