@@ -1,7 +1,7 @@
 /*
- *  Copyright (C) 2004 Adam Hooper
- *  Copyright (C) 2004, 2005 Jean-François Rameau
- *  Copyright (C) 2004, 2005 Christian Persch
+ *  Copyright © 2004 Adam Hooper
+ *  Copyright © 2004, 2005 Jean-François Rameau
+ *  Copyright © 2004, 2005, 2008 Christian Persch
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,14 +17,12 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: mozilla-helpers.h,v 1.13 2005/03/02 19:49:47 chpe Exp $
+ *  $Id: mozilla-helpers.h 1725 2008-05-18 21:51:00Z chpe $
  */
 
 #ifndef PAGE_INFO_MOZILLA_HELPERS_H
 #define PAGE_INFO_MOZILLA_HELPERS_H
 
-#include "config.h"
-
 #include <glib.h>
 
 #include <epiphany/ephy-embed.h>
@@ -72,13 +70,16 @@ typedef struct
 	*/
 } EmbedPageProperties;
 
-typedef enum 
+/* take care to sort enum by name */
+/* so we can sort media as well */
+typedef enum
 {
-  MEDIUM_IMAGE,
-  MEDIUM_EMBED,
-  MEDIUM_OBJECT,
   MEDIUM_APPLET,
+  MEDIUM_EMBED,
   MEDIUM_ICON,
+  MEDIUM_IMAGE,
+  MEDIUM_BG_IMAGE,
+  MEDIUM_OBJECT,
   LAST_MEDIUM
 } EmbedPageMediumType;
 
@@ -90,7 +91,7 @@ typedef struct
   char *title;
   int width;
   int height;
-} EmbedPageMedium; 
+} EmbedPageMedium;
 
 typedef struct
 {
@@ -126,6 +127,8 @@ EmbedPageInfo *mozilla_get_page_info        (EphyEmbed *embed);
 
 void           mozilla_free_embed_page_info (EmbedPageInfo *info);
 
+gboolean       mozilla_glue_startup         (void);
+
 G_END_DECLS
 
 #endif /* PAGE_INFO_MOZILLA_HELPERS_H */
